@@ -11,7 +11,7 @@ class _CredentialBase(FeatureBase):
     def __init__(self, api):
         super().__init__(api=api)
 
-    def _create(self, name: str, parent_folder: 'Union[Config.Object]', friendly_name: str, values: List[dict], expiration: int,
+    def _create(self, name: str, parent_folder: 'Union[Config.Object, str]', friendly_name: str, values: List[dict], expiration: int,
                 description: str = None, encryption_key: str = None, shared: bool = False, contacts: 'List[Union[Identity.Identity, str]]' = None,
                 get_if_already_exists: bool = True):
         parent_folder_dn = self._get_dn(parent_folder)
@@ -42,7 +42,8 @@ class _CredentialBase(FeatureBase):
         Args:
             credential: :ref:`config_object` or :ref:`dn` of the credential object.
         """
-        result = self._api.websdk.Credentials.Delete.post(credential_path=credential.dn).result
+        credential_dn = self._get_dn(credential)
+        result = self._api.websdk.Credentials.Delete.post(credential_path=credential_dn).result
         if result.code != 1:
             raise InvalidResultCode(code=result.code, code_description=result.credential_result)
 
@@ -66,7 +67,7 @@ class AmazonCredential(_CredentialBase):
     def __init__(self, api):
         super().__init__(api)
 
-    def create_adfs(self, name: str, parent_folder: 'Union[Config.Object]', adfs_credential: 'Union[Config.Object, str]', adfs_url: str,
+    def create_adfs(self, name: str, parent_folder: 'Union[Config.Object, str]', adfs_credential: 'Union[Config.Object, str]', adfs_url: str,
                     role: str, expiration: int = 6, description: str = None, encryption_key: str = None, shared: bool = False,
                     contacts: 'List[Union[Identity.Identity, str]]' = None, get_if_already_exists: bool = True):
         """
@@ -105,7 +106,7 @@ class AmazonCredential(_CredentialBase):
             get_if_already_exists=get_if_already_exists
         )
 
-    def create_local(self, name: str, parent_folder: 'Union[Config.Object]', access_key: str, secret_key: str, role: str = None,
+    def create_local(self, name: str, parent_folder: 'Union[Config.Object, str]', access_key: str, secret_key: str, role: str = None,
                      external_id: str = None, expiration: int = 6, description: str = None, encryption_key: str = None,
                      shared: bool = False, contacts: 'List[Union[Identity.Identity, str]]' = None, get_if_already_exists: bool = True):
         """
@@ -152,7 +153,7 @@ class CertificateCredential(_CredentialBase):
     def __init__(self, api):
         super().__init__(api)
 
-    def create(self, name: str, parent_folder: 'Union[Config.Object]', certificate: str, password: str = None, expiration: int = 6,
+    def create(self, name: str, parent_folder: 'Union[Config.Object, str]', certificate: str, password: str = None, expiration: int = 6,
                description: str = None, encryption_key: str = None, shared: bool = False, contacts: 'List[Union[Identity.Identity, str]]' = None,
                get_if_already_exists: bool = True):
         """
@@ -238,7 +239,7 @@ class GenericCredential(_CredentialBase):
     def __init__(self, api):
         super().__init__(api)
 
-    def create(self, name: str, parent_folder: 'Union[Config.Object]', generic: str, password: str = None, expiration: int = 6,
+    def create(self, name: str, parent_folder: 'Union[Config.Object, str]', generic: str, password: str = None, expiration: int = 6,
                description: str = None, encryption_key: str = None, shared: bool = False, contacts: 'List[Union[Identity.Identity, str]]' = None,
                get_if_already_exists: bool = True):
         """
@@ -281,7 +282,7 @@ class PasswordCredential(_CredentialBase):
     def __init__(self, api):
         super().__init__(api)
 
-    def create(self, name: str, parent_folder: 'Union[Config.Object]', password: str, expiration: int = 6, description: str = None,
+    def create(self, name: str, parent_folder: 'Union[Config.Object, str]', password: str, expiration: int = 6, description: str = None,
                encryption_key: str = None, shared: bool = False, contacts: 'List[Union[Identity.Identity, str]]' = None,
                get_if_already_exists: bool = True):
         """
@@ -322,7 +323,7 @@ class PrivateKeyCredential(_CredentialBase):
     def __init__(self, api):
         super().__init__(api)
 
-    def create(self, name: str, parent_folder: 'Union[Config.Object]', private_key: str, username: str, expiration: int = 6,
+    def create(self, name: str, parent_folder: 'Union[Config.Object, str]', private_key: str, username: str, expiration: int = 6,
                description: str = None, encryption_key: str = None, shared: bool = False, contacts: 'List[Union[Identity.Identity, str]]' = None,
                get_if_already_exists: bool = True):
         """
@@ -365,7 +366,7 @@ class UsernamePasswordCredential(_CredentialBase):
     def __init__(self, api):
         super().__init__(api)
 
-    def create(self, name: str, parent_folder: 'Union[Config.Object]', username: str, password: str, expiration: int = 6,
+    def create(self, name: str, parent_folder: 'Union[Config.Object, str]', username: str, password: str, expiration: int = 6,
                description: str = None, encryption_key: str = None, shared: bool = False, contacts: 'List[Union[Identity.Identity, str]]' = None,
                get_if_already_exists: bool = True):
         """
